@@ -3,7 +3,11 @@ from contextlib import contextmanager
 from typing import Dict, Generator, List
 
 import httpx
-from chaoslib.discovery.discover import initialize_discovery_result
+from chaoslib.discovery.discover import (
+    discover_activities,
+    discover_probes,
+    initialize_discovery_result,
+)
 from chaoslib.types import (
     Configuration,
     DiscoveredActivities,
@@ -13,15 +17,13 @@ from chaoslib.types import (
 from logzero import logger
 
 try:
-    from opentelemetry.instrumentation.httpx import (  # type: ignore
-        HTTPXClientInstrumentor,
-    )
+    from opentelemetry.instrumentation.httpx import HTTPXClientInstrumentor
 
     HTTPXClientInstrumentor().instrument()
 except ImportError:
     pass
 
-__version__ = "0.9.4"
+__version__ = "0.10.0"
 __all__ = ["get_session", "discover"]
 RELIABLY_HOST = "app.reliably.com"
 
@@ -89,6 +91,18 @@ def load_exported_activities() -> List[DiscoveredActivities]:
     Extract metadata from actions, probes and tolerances
     exposed by this extension.
     """
-    activities = []  # type: ignore
+    activities = []
+    activities.extend(
+        discover_activities(
+            "chaosreliably.activities.http.tolerances", "tolerance"
+        )
+    )
+    activities.extend(discover_probes("chaosreliably.activities.http.probes"))
+    activities.extend(
+        discover_activities(
+            "chaosreliably.activities.tls.tolerances", "tolerance"
+        )
+    )
+    activities.extend(discover_probes("chaosreliably.activities.tls.probes"))
 
     return activities
